"""Initialize GEE."""

import os
import json

import ee


def ee_initialize(token_name, project, **kwargs):
    r"""Initialize GEE.

    :param token_name: The name of the Earth Engine token.

    :param project: Name of the Google Cloud project.

    :param \**kwargs: See below

    :Keyword Arguments:
        Additional parameters for ee.Initialize(). For
        example,
        opt_url='https://earthengine-highvolume.googleapis.com' to use
        the Earth Engine High-Volume platform.

    """

    # Get credentials from environmental variable
    ee_token = os.environ.get(token_name)
    credential_file_path = os.path.expanduser(
        "~/.config/earthengine/credentials")

    # Write credentials
    if not os.path.exists(credential_file_path):
        os.makedirs(
            os.path.dirname(credential_file_path), exist_ok=True
        )
        if ee_token.startswith("{") and ee_token.endswith("}"):
            # deals with token generated by new auth method
            # (earthengine-api >= 0.1.304).
            token_dict = json.loads(ee_token)
            with open(credential_file_path, "w", encoding="utf-8") as f:
                f.write(json.dumps(token_dict))
        else:
            credential = (
                '{"refresh_token":"%s"}' % ee_token
            )  # deals with token generated by old auth method.
            with open(credential_file_path, "w", encoding="utf-8") as f:
                f.write(credential)

    # Initialize
    ee.Initialize(project=project,
                  **kwargs)
